@@ -1,6 +1,6 @@
 import csv
 import json
-import os
+from pathlib import Path
 import isodate
 import logging
 import datetime
@@ -115,6 +115,10 @@ class CSVFormat(FileFormat):
         'datetime': {
             'format': DATETIME_P_FORMAT
         },
+        'boolean': {
+            'trueValues': ['True'],
+            'falseValues': ['False']
+        }
     }
 
     def __init__(self, file, schema, use_titles=False, **options):
@@ -131,8 +135,7 @@ class CSVFormat(FileFormat):
     def prepare_resource(cls, resource):
         descriptor = resource.descriptor
         descriptor['encoding'] = 'utf-8'
-        basename, _ = os.path.splitext(descriptor['path'])
-        descriptor['path'] = basename + '.csv'
+        descriptor['path'] = str(Path(descriptor['path']).with_suffix('.csv'))
         descriptor['format'] = 'csv'
         descriptor['dialect'] = dict(
             lineTerminator='\r\n',
@@ -188,10 +191,10 @@ class JSONFormat(FileFormat):
     def prepare_resource(cls, resource):
         descriptor = resource.descriptor
         descriptor['encoding'] = 'utf-8'
-        basename, _ = os.path.splitext(resource.source)
-        descriptor['path'] = basename + '.json'
+        descriptor['path'] = str(Path(descriptor['path']).with_suffix('.json'))
         descriptor['format'] = 'json'
         descriptor['mediatype'] = 'text/json'
+        descriptor['profile'] = 'tabular-data-resource'
         super(JSONFormat, cls).prepare_resource(resource)
 
     def write_transformed_row(self, transformed_row):
